@@ -21,6 +21,6 @@
 
 # Runs Test:
 
-	runsTest(nyseres[, 1], doprint = TRUE)
+	runsTest(nyseres[, 1])
 
 	
\ No newline at end of file
